Cheesy Potato Bake with Eggs - Recipe.com

# Cheesy Potato Bake with Eggs

Recipe from Better Homes and Gardens
SERVINGS
8 to 12
PREP TIME
30 mins

- 5
- 4
- 3
- 2
- 1

by 23 people
read comments

- 5
- 4
- 3
- 2
- 1

add your rating
add a comment

#### Related Categories:

Breakfast and Brunch, Vegetables
Ingredients

- 1 medium onion, finely chopped
- 2 tablespoons butter
- 4 teaspoons all-purpose flour
- 1 1/2 cups milk
- 8 ounces sharp cheddar cheese, shredded (2 cups)
- 3 pounds russet potatoes, peeled and thinly sliced*
- 1 1/2 cups chopped fresh broccoli
- 1 tablespoon vegetable oil
- 8 eggs
- 2 tablespoons milk
- 6 slices bacon, crisp-cooked, drained, and crumbled
- 1 large tomato, chopped

Related Video
How to Make Polenta Sausage Bowl

The delicious combination of Italian sausage and dried Italian seasonings add a kick to this nutritious Polenta-Sausage Bowl. The tomatoes, mushrooms, and zucchini within the mix provides an appealing visual array of colors.

more videos
Directions
1.
Preheat oven to 325 degrees F. In a medium saucepan cook onion in butter over medium heat for 4 minutes or until tender, stirring occasionally. Stir in flour, 1/2 tsp. salt, and 1/2 tsp. ground black pepper. Stir in milk; cook and stir until slightly thickened and bubbly. Stir in cheese until melted.
2.
In a 3-quart baking dish, layer potatoes, then cheese sauce. Bake, covered, about 55 minutes, until potatoes are tender.
3.
In a large skillet, cook broccoli in hot oil over medium heat for 5 minutes, until nearly tender, stirring frequently. In a large bowl, beat together eggs, water, 1/2 tsp. salt, and 1/4 tsp. ground black pepper. Pour over broccoli in skillet. Cook over medium heat, without stirring, until mixture begins to set on bottom and around edges. Using a spatula, lift and fold partially cooked egg so uncooked portion flows underneath. Cook 2 minutes more or until egg is cooked yet still moist. Spoon over potatoes. Top with bacon and chopped tomato. Serve immediately.

### Tip

- Quickly slice potatoes with a food processor or mandolin slicer.

#### nutrition information

Per Serving: cal. (kcal) 421, Fat, total (g) 22, chol. (mg) 259, sat. fat (g) 11, carb. (g) 36, Monosaturated fat (g) 7, Polyunsaturated fat (g) 3, Trans fatty acid (g) 0, fiber (g) 3, sugar (g) 7, pro. (g) 21, vit. A (IU) 972, vit. C (mg) 35, Thiamin (mg) 0, Riboflavin (mg) 1, Niacin (mg) 3, Pyridoxine (Vit. B6) (mg) 1, Folate (µg) 60, Cobalamin (Vit. B12) (µg) 1, sodium (mg) 708, Potassium (mg) 837, calcium (mg) 313, iron (mg) 2, Percent Daily Values are based on a 2,000 calorie diet
Comments
Related Recipe
Bacon and Baked Potato Soup

- 5
- 4
- 3
- 2
- 1

- #### More Recipes Like This

- Carrot and Bacon Quiche
- Chef's Garden Salad
- Bacon and Dried Tomato Scones

More Great Recipe Ideas from Better Homes and Gardens

- Super Slow-Cooker Chicken
- Our Best 20-Minute Meals
- Subscribe - Free Year
- Cooking time and temperature charts

the buzz list

Fried Risotto Balls: Reinventing Last Night's Leftovers

Chocolate Lover's Dessert: Rocky Road Ice Cream

Make this Drink: Rum, Coconut, and Lime Cocktail

Our Favorite Chicken Casseroles

Make-Ahead Breakfast: Swiss Chard, Pepper, and Tomato Quiche

See More Shop Related Products

Richelieu

Richelieu 44804 Beech Universal Spice Rack 150 MM

$94.00

Efaucets.com

Richelieu

Richelieu 80096170 Stainless Steel Universal Spice Rack

$118.00

Efaucets.com

Fuller Brush

Fuller Brush Bamboo Salt Box

$19.00

Fuller Brush Products

Wine Enthusiast

NitroTap & Winekeeper Replacment Canisters (Set of 4)

$79.00

Wine Enthusiast

Wine Enthusiast

Personalized Wine Bottle Pepper Mill (Ebony)

$59.00

Wine Enthusiast

Wine Enthusiast

Personalized Wine Bottle Salt Mill

$59.00

Wine Enthusiast
Back to Top